@@ -28,7 +28,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 
 ###############################################################################
@@ -58,7 +58,6 @@ sub new {
     $self->{_fileclosed}       = 0;
     $self->{_biffsize}         = 0;
     $self->{_sheetname}        = "Sheet";
-    $self->{_codepage}         = 0x04E4;
     $self->{_worksheets}       = [];
     $self->{_sheetnames}       = [];
     $self->{_formats}          = [];
@@ -498,23 +497,6 @@ sub set_tempdir {
 }
 
 
-###############################################################################
-#
-# set_codepage()
-#
-# See also the _store_codepage method. This is used to store the code page, i.e.
-# the character set used in the workbook.
-#
-sub set_codepage {
-
-    my $self = shift;
-    my $codepage = $_[0] || 1;
-    $codepage = 0x04E4 if $codepage == 1;
-    $codepage = 0x8000 if $codepage == 2;
-    $self->{_codepage} = $codepage;
-}
-
-
 ###############################################################################
 #
 # _store_workbook()
@@ -917,6 +899,17 @@ sub _quote_sheetname {
 }
 
 
+###############################################################################
+#
+# Deprecated methods for backwards compatibility.
+#
+###############################################################################
+
+# No longer required by Excel::Writer::XLSX.
+sub compatibility_mode { }
+sub set_codepage       { }
+
+
 ###############################################################################
 #
 # XML writing methods.
